# Changelog

## 0.1.0 (2025-05-28)


### Features

* **api:** イベント一覧取得を追加 ([faffb0b](https://github.com/ryohidaka/connpass-py/commit/faffb0b801109699b679244b40edd83db2b7ea43))
* **client:** Connpass API にアクセスするためのクライアントを作成 ([89ae756](https://github.com/ryohidaka/connpass-py/commit/89ae756bf3130c828321af8a44c71eb02b91f04a))
* **client:** 共通リクエストハンドラーを追加 ([2abe93f](https://github.com/ryohidaka/connpass-py/commit/2abe93fcdc3c80fce67748cdad70685e9014ae9e))
* **examples:** イベント一覧取得のサンプルを追加 ([cd7ddb4](https://github.com/ryohidaka/connpass-py/commit/cd7ddb44acde5ecda00caeb3e32a5219727707e4))
* **models:** イベント一覧の型定義を追加 ([998b8c7](https://github.com/ryohidaka/connpass-py/commit/998b8c75123b28ca9975cdd190c98acdba716ed9))
* **package:** pydantic をインストール ([802a66f](https://github.com/ryohidaka/connpass-py/commit/802a66f18fa631798d25fddc0989c6f3c1f6f1e1))
* **package:** pyproject.toml を更新 ([e5e1775](https://github.com/ryohidaka/connpass-py/commit/e5e177599c1571792a24b39ba9be6e831f90d07f))
* **package:** pytest をインストール ([01b2c90](https://github.com/ryohidaka/connpass-py/commit/01b2c906c238fbdb4a75aac30a1291c50608e647))
* **package:** pytest-cov をインストール ([f49c911](https://github.com/ryohidaka/connpass-py/commit/f49c91178115ce0f5188b03785fdd68ab9d83b7f))
* **package:** requests-mockをインストール ([a68460e](https://github.com/ryohidaka/connpass-py/commit/a68460e558b1c4c0f1d0a0d3192d3a3c243b7e5e))
* **package:** ruffをインストール ([6563ebf](https://github.com/ryohidaka/connpass-py/commit/6563ebfc3a9b29a85f756f9678027710c56497d1))


### Documentation

* README.md を更新 ([57e762f](https://github.com/ryohidaka/connpass-py/commit/57e762f8f187cf52f227a4399aaa481b6f1908c9))


### Miscellaneous Chores

* release 0.1.0 ([976bd21](https://github.com/ryohidaka/connpass-py/commit/976bd210465554e97d6c6dba2c931d70a3c615d6))
